CREATE DATABASE MythsRealities

USE  MythsRealities

-- TRUNCATE CAN NOT BE ROLLED BACK

CREATE TABLE TestTable (strRoll CHAR(6), StrName VARCHAR(50))
GO
INSERT INTO TestTable VALUES('100001','A')
INSERT INTO TestTable VALUES('100002','B')
INSERT INTO TestTable VALUES('100003','C')
INSERT INTO TestTable VALUES('100004','D')
GO


-- Page Allocations

DBCC IND (MythsRealities, TestTable, 0);
GO

-- Locks

SELECT resource_type, resource_description, request_mode FROM sys.dm_tran_locks WHERE resource_type IN ('EXTENT', 'PAGE');

BEGIN TRAN
TRUNCATE TABLE TestTable
SELECT * FROM TestTable

ROLLBACK
SELECT * FROM TestTable

--------------------------------------------------------------------------------------------------
-- SELECT COUNT (*) will force a table/clustered index scan

create table tExample(
intSlno int identity(1001,1),
strName varchar(50) NOT NULL default '',
strDept char(5) NOT NULL check (strDept >''),
strCity varchar(50) NULL default 'Chennai')
go

create clustered index CI_tExample2_Slno on tExample (intSlno)
go
create nonclustered index CI_tExample2_Dept on tExample (strDept)
go

set nocount on
insert into tExample(strName, strDept, strCity) values ( 'AAAAA', 'EAS' , 'CHENNAI')
go 1000

-- Check execution plans of below query
select count(*) from tExample

---------------------------------------------------------------------------------------------------
-- NULL wont occupy space in SQL Server

-- VARCHAR

drop table tvarCharTest
go

create table tvarCharTest(strCol1 varchar(1000))
go

set nocount on
go
insert into tvarCharTest values ('AAAA')
go

select * from tvarCharTest

-- pages allocated for a table
DBCC TRACEON(3604)
DBCC IND('MythsRealities', 'tvarCharTest', -1)
DBCC TRACEOFF(3604)


DBCC TRACEON(3604)
DBCC PAGE(MythsRealities, 1, 168, 1)-- WITH TABLERESULTS
DBCC TRACEOFF(3604)

-- CHAR

drop table tCharTest
go

create table tCharTest(strCol1 char(1000))
go

set nocount on
go
insert into tCharTest values ('AAAA')
go

select * from tCharTest

-- pages allocated for a table
DBCC TRACEON(3604)
DBCC IND('MythsRealities', 'tCharTest', -1)
DBCC TRACEOFF(3604)


DBCC TRACEON(3604)
DBCC PAGE(MythsRealities, 1, 166, 1)-- WITH TABLERESULTS
DBCC TRACEOFF(3604)

---------------------------------------------------------------------------------------------------
-- Rows in Clustered index table are physically sorted based on clustered index key

use MythsRealities
go

drop table Employee
go

create table Employee(
intEmpId char(6),
strFirstName varchar(100),
strLastName varchar(100),
strDeptId varchar(6))
go

create clustered index CI_Employee_intEmpId on Employee (intEmpId)
go

set nocount on
go

insert into employee(intEmpId, strFirstName, strLastName, strDeptId) values ('230829', 'AAA','AAA','DEPT01')
insert into employee(intEmpId, strFirstName, strLastName, strDeptId) values ('415036', 'AAA','AAA','DEPT01')
insert into employee(intEmpId, strFirstName, strLastName, strDeptId) values ('737534', 'AAA','AAA','DEPT01')
insert into employee(intEmpId, strFirstName, strLastName, strDeptId) values ('116036', 'AAA','AAA','DEPT01')
insert into employee(intEmpId, strFirstName, strLastName, strDeptId) values ('724706', 'AAA','AAA','DEPT01')
insert into employee(intEmpId, strFirstName, strLastName, strDeptId) values ('140202', 'AAA','AAA','DEPT01')
insert into employee(intEmpId, strFirstName, strLastName, strDeptId) values ('721413', 'AAA','AAA','DEPT01')
insert into employee(intEmpId, strFirstName, strLastName, strDeptId) values ('230829', 'AAA','AAA','DEPT01')
insert into employee(intEmpId, strFirstName, strLastName, strDeptId) values ('405544', 'AAA','AAA','DEPT01')
insert into employee(intEmpId, strFirstName, strLastName, strDeptId) values ('683563', 'AAA','AAA','DEPT01')

select * from employee

-- pages allocated for a table
DBCC TRACEON(3604)
DBCC IND('MythsRealities', 'employee', -1)
DBCC TRACEOFF(3604)


DBCC TRACEON(3604)
DBCC PAGE(MythsRealities, 1, 167, 2)-- WITH TABLERESULTS
DBCC TRACEOFF(3604)
